@@ -202,7 +202,9 @@ async def create_group_v1_post(
         number = number or app.config.ACCOUNT
     except AttributeError:
         return json(
-            {"error": "number missing in request and PYTHON_SIGNAL_CLI_REST_API_ unset "},
+            {
+                "error": "number missing in request and PYTHON_SIGNAL_CLI_REST_API_ unset "
+            },
             400,
         )
     uuid = str(uuid4())
