@@ -105,7 +105,9 @@ async def send_v2_post(
         number = body.number or app.config.ACCOUNT
     except AttributeError:
         return json(
-            {"error": "number missing in request and PYTHON_SIGNAL_CLI_REST_API_ unset "},
+            {
+                "error": "number missing in request and PYTHON_SIGNAL_CLI_REST_API_ unset "
+            },
             400,
         )
     attachments = body.base64_attachments
@@ -158,7 +160,9 @@ async def send_v1_post(
         number = body.number or app.config.ACCOUNT
     except AttributeError:
         return json(
-            {"error": "number missing in request and PYTHON_SIGNAL_CLI_REST_API_ unset "},
+            {
+                "error": "number missing in request and PYTHON_SIGNAL_CLI_REST_API_ unset "
+            },
             400,
         )
     attachments = body.base64_attachments
